@@ -26,6 +26,10 @@ class RegexType:
         def my_command(args: Namespace):
             print(args.option)
 
+        @app.command
+        def my_command(*, alpha: RegexType(r"[a-z]+")):
+            print(alpha)
+
     From CLI::
 
         > my_app m_command --alpha abc
@@ -39,7 +43,7 @@ class RegexType:
         self._re = re.compile(regex)
         self._message = message or f"Value does not match {self._re.pattern!r}"
 
-    def __call__(self, string):
-        if not self._re.search(string):
+    def __call__(self, string) -> str:
+        if not self._re.match(string):
             raise argparse.ArgumentTypeError(self._message)
         return string
